use duckdb::{params, Connection};

const ROOT: &str = "s3://overturemaps-us-west-2/release/2025-03-19.0";

fn main() -> Result<(), Box<dyn std::error::Error>> {
    let conn = Connection::open("test.map")?;
    conn.execute_batch(
        r#"
        install httpfs;
        load httpfs;
        install spatial;
        load spatial;
        set s3_access_key_id = '';
        set s3_secret_access_key = '';
        set s3_region='us-west-2';
        set preserve_insertion_order = false;
        "#,
    )?;
    let xmin = -97.734375;
    let xmax = -97.3828125;
    let ymin = 30.234375;
    let ymax = 30.41015625;
    let types = vec![
        "theme=places/type=place",
        "theme=buildings/type=building",
        "theme=transportation/type=segment",
        "theme=transportation/type=connector",
    ];
    for t in &types {
        let table = t.split('=');
        let table = table.last().unwrap();
        let root = format!("{ROOT}/{t}/*");
        println!("Making table");
        println!(
            r#"create table {table} as select * from read_parquet("{root}") where bbox.xmin between {xmin} and {xmax} and bbox.ymin between {ymin} and {ymax};"#
        );
        let query = format!(
            r#"create table {table} as select * from read_parquet(?) where bbox.xmin between ? and ? and bbox.ymin between ? and ?;"#
        );
        conn.execute(&query, params![root, xmin, xmax, ymin, ymax,])?;
    }
    Ok(())
}
